@@ -12,10 +12,13 @@ It also includes the main :class:`TexasHoldEm` class.
 from __future__ import annotations
 import os
 from typing import Iterator, Callable, Dict, Tuple, Optional, Union, List, Iterable
+from collections import deque
 from enum import Enum, auto
 import random
 import warnings
 
+from deprecated.sphinx import versionadded, versionchanged
+
 from texasholdem.card.card import Card
 from texasholdem.card.deck import Deck
 from texasholdem.game.history import (History, PrehandHistory,
@@ -61,7 +64,7 @@ class Pot:
     Attributes:
         amount (int): The amount of chips in the pot NOT including the current betting round
         raised (int): The highest bet amount in the current betting round
-        player_amounts (Dict[int, int]): A map from player id to # chips each player has posted
+        player_amounts (dict[int, int]): A map from player id to # chips each player has posted
                                          this round
 
     """
@@ -223,14 +226,14 @@ class TexasHoldEm:
         big_blind (int): Big blind
         small_blind (int): Small blind
         max_players (int): how many players can sit at the table, defaults to 9.
-        players (List[Player]): A list of all players in the game.
+        players (list[Player]): A list of all players in the game.
         btn_loc (int): The id of the player who has the button.
         bb_loc (int): The id of the player who has the big blind.
         sb_loc (int): The id of the player who has the small blind.
         current_player (int): The id of the player who is to act.
-        pots (List[Pot]): The active :class:`Pot` objects in the game.
-        board (List[Card]): The communal cards that are out.
-        hands (dict[int, List[Card]]): Map from player id to their hand
+        pots (list[Pot]): The active :class:`Pot` objects in the game.
+        board (list[Card]): The communal cards that are out.
+        hands (dict[int, list[Card]]): Map from player id to their hand
         last_raise (int): The amount of the last raise (that was over the previous bet)
         raise_option (bool): If the current player has the option to raise (not taking into account
             chip count). This is usually true and is only useful in the context of WSOP 2021 Rule 96
@@ -248,7 +251,7 @@ class TexasHoldEm:
         self.small_blind = small_blind
         self.max_players = max_players
 
-        self.players: List[Player] = list(Player(i, self.buyin) for i in range(max_players))
+        self.players: list[Player] = list(Player(i, self.buyin) for i in range(max_players))
 
         self.btn_loc = random.choice(self.players).player_id
         self.bb_loc = -1
@@ -390,7 +393,7 @@ class TexasHoldEm:
             loc (int, optional): The location to start at, defaults to current_player
             reverse (bool): In reverse play order, default False
         Returns:
-            Iterator[int]: An iterator over all active player ids starting at loc
+            Iterator[int]: An iterator over players with a stake in the pot
 
         """
         if loc is None:
@@ -628,6 +631,7 @@ class TexasHoldEm:
                    for i in range(len(self.pots))
                    if player_id in self._get_pot(i).players_in_pot())
 
+    @versionadded(version="0.6.0")
     def total_to_value(self, total: Optional[int], player_id: int) -> Optional[int]:
         """
         Translates a raise phrase "raise *to* total" to the phrase
@@ -637,27 +641,29 @@ class TexasHoldEm:
             total (int, optional): A total amount to raise
             player_id (int): The player who's doing the raising
         Returns:
-            Optional[int]: A translation to an amount the player is raising *to*
+            Optional[int]: A translation to an amount the player is raising *by*
         """
         if not total:
             return None
         return total - self.chips_to_call(player_id) - self.player_bet_amount(player_id)
 
+    @versionadded(version="0.6.0")
     def value_to_total(self, value: Optional[int], player_id: int) -> Optional[int]:
         """
         Translates a raise phrase "raise value" to the phrase
         "raise *to* total".
 
         Arguments:
-            value (int, optional): An amount to raise past the any other bet
+            value (int, optional): An amount to raise past the previous bet
             player_id (int): The player who's doing the raising
         Returns:
-            Optional[int]: A translation to an amount the player is raising *by*
+            Optional[int]: A translation to an amount the player is raising *to*
         """
         if not value:
             return None
         return value + self.chips_to_call(player_id) + self.player_bet_amount(player_id)
 
+    @versionadded(version="0.6.0")
     def min_raise(self):
         """
         Returns:
@@ -666,6 +672,12 @@ class TexasHoldEm:
         return max(self.big_blind, self.last_raise)
 
     @check_raise(ValueError)
+    @versionchanged(reason=
+                    "The :code:`value` has been renamed to :code:`total` and will "
+                    "be redefined in 1.0.0. Currently, :code:`value` and :code:`total` "
+                    "mean to raise *to* the amount given. In 1.0.0, :code:`value` will "
+                    "mean to raise an amount more than the current bet amount.",
+                    version="0.6.0")
     def validate_move(self,
                       player_id: Optional[int] = None,
                       action: Optional[ActionType] = None,
@@ -680,11 +692,6 @@ class TexasHoldEm:
         .. note::
             :code:`value` and :code:`total` are mutually exclusive.
 
-        .. deprecated:: 0.6
-            The :code:`value` argument will be redefined in 1.0. Currently, :code:`value`
-            and :code:`total` mean to raise *to* the amount given. In 1.0, :code:`value`
-            will mean to raise an amount more than the current bet amount.
-
         Arguments:
             player_id (int, optional): The player to take action. Default current_player.
             action (int, optional): The ActionType to take
@@ -705,10 +712,12 @@ class TexasHoldEm:
             raise ValueError("Got arguments for both total and value. Expected only one.")
 
         if value:
-            warnings.warn("The value argument will be redefined in 1.0. Currently, value "
-                          "and total mean to raise *to* the amount given. In 1.0, value will "
-                          "mean to raise an amount more than the current bet amount.",
-                          DeprecationWarning)
+            warnings.warn(
+                "The :code:`value` has been renamed to :code:`total` and will "
+                "be redefined in 1.0.0. Currently, :code:`value` and :code:`total` "
+                "mean to raise *to* the amount given. In 1.0.0, :code:`value` will "
+                "mean to raise an amount more than the current bet amount.",
+                DeprecationWarning)
             total = value
 
         # ALL_IN should be translated
@@ -729,16 +738,16 @@ class TexasHoldEm:
         if new_action == ActionType.CALL and \
                 self.players[player_id].state != PlayerState.TO_CALL:
             return False, f"Player {player_id} has state " \
-                          f"{self.players[player_id].state} cannot CALL"
+                          f"{self.players[player_id].state.name} cannot CALL"
 
         if new_action == ActionType.CHECK and \
                 self.players[player_id].state != PlayerState.IN:
             return False, \
-                   f"Player {player_id} has state {self.players[player_id].state} cannot CHECK"
+                   f"Player {player_id} has state {self.players[player_id].state.name} cannot CHECK"
 
         if new_action == ActionType.RAISE:
-            if new_total is None:
-                return False, "Expected value to not be None for action RAISE."
+            if new_total is None or new_total == 0:
+                return False, "Expected value to not be None or 0 for action RAISE."
 
             if not self.raise_option:
                 return False, "Betting round is over at this point, can only CALL or FOLD."
@@ -803,18 +812,16 @@ class TexasHoldEm:
         return ActionType.RAISE, \
             self.player_bet_amount(self.current_player) + self.players[self.current_player].chips
 
-    def _previous_all_in_sum(self, history_len: int) -> int:
+    def _previous_all_in_sum(self) -> int:
         """
         Used for WSOP Rule 96
 
-        Arguments:
-            history_len (int): How far back to go
         Returns:
             int: The sum of the raise values of the most recent all-in raise players.
         """
         raised_sum = 0
 
-        for action in reversed(self.hand_history[self.hand_phase].actions[-history_len:]):
+        for action in reversed(self.hand_history[self.hand_phase].actions):
             if self.players[action.player_id].state == PlayerState.ALL_IN \
                     and action.action_type == ActionType.RAISE:
                 raised_sum += action.value
@@ -830,6 +837,9 @@ class TexasHoldEm:
 
         Arguments:
             hand_phase (HandPhase): Which betting round phase to execute
+        Returns:
+            Iterator[TexasHoldEm]: An iterator over the intermediary game states right when
+                a player is expected to take a turn.
         Raises:
             ValueError: If self.hand_state is not a valid betting round
 
@@ -858,16 +868,16 @@ class TexasHoldEm:
         if hand_phase == HandPhase.PREFLOP:
             self.current_player = self.bb_loc + 1
 
-        i, player_list = 0, list(self.active_iter(self.current_player))
+        player_queue = deque(self.active_iter(self.current_player))
 
         while not self._is_hand_over():
             # WSOP 2021 Rule 96
             # if no more active players that can raise continue with the players to call
             # while disabling the raise availability.
-            if i >= len(player_list):
-                i, player_list = 0, list(self.player_iter(loc=self.current_player + 1,
-                                                          match_states=(PlayerState.TO_CALL,)))
-                if not player_list:
+            if not player_queue:
+                player_queue = deque(self.player_iter(loc=self.current_player + 1,
+                                                      match_states=(PlayerState.TO_CALL,)))
+                if not player_queue:
                     break
 
                 self.raise_option = False
@@ -876,7 +886,7 @@ class TexasHoldEm:
             prev_raised = self.last_raise
 
             # set the current player and yield
-            self.current_player = player_list[i]
+            self.current_player = player_queue.popleft()
             yield self
 
             action, total = self._translate_allin(*self._action)
@@ -900,34 +910,31 @@ class TexasHoldEm:
                 # An all-in raise less than the previous raise shall not reopen
                 # the bidding unless two or more such all-in raises total greater
                 # than or equal to the previous raise.
-                raise_sum = self._previous_all_in_sum(len(player_list))
+                raise_sum = self._previous_all_in_sum()
                 if value < prev_raised:
                     if raise_sum < prev_raised:
-                        i += 1
                         continue
                     # Exception for rule 96, set this
                     self.last_raise = raise_sum
 
                 # reset the round (i.e. as if the betting round started here)
-                i, player_list = 0, list(self.active_iter(self.current_player))
+                player_queue = deque(self.active_iter(self.current_player))
 
                 # Throwaway current player
                 # Edge case: active_iter already excludes ALL_IN
                 if self.players[self.current_player].state != PlayerState.ALL_IN:
-                    player_list.pop(0)
-            else:
-                i += 1
+                    player_queue.popleft()
 
         # consolidate betting to all pots in this betting round
         for i in range(first_pot, len(self.pots)):
             self._get_pot(i).collect_bets()
 
-    def get_hand(self, player_id) -> List[Card]:
+    def get_hand(self, player_id) -> list[Card]:
         """
         Arguments:
             player_id (int): The player id
         Returns:
-            List[Card]: A two element list of the hand of the given player,
+            list[Card]: A two element list of the hand of the given player,
                 if the player has not been dealt a hand, returns an empty list
 
         """
@@ -959,6 +966,12 @@ class TexasHoldEm:
         except StopIteration:
             pass
 
+    @versionchanged(reason=
+                    "The :code:`value` has been renamed to :code:`total` and will "
+                    "be redefined in 1.0.0. Currently, :code:`value` and :code:`total` "
+                    "mean to raise *to* the amount given. In 1.0.0, :code:`value` will "
+                    "mean to raise an amount more than the current bet amount.",
+                    version="0.6.0")
     def take_action(self,
                     action_type: ActionType,
                     value: Optional[int] = None,
@@ -969,11 +982,6 @@ class TexasHoldEm:
         .. note::
             :code:`value` and :code:`total` are mutually exclusive.
 
-        .. deprecated:: 0.6
-            The :code:`value` argument will be redefined in 1.0. Currently, :code:`value`
-            and :code:`total` mean to raise *to* the amount given. In 1.0, :code:`value`
-            will mean to raise an amount more than the current bet amount.
-
         Arguments:
             action_type (ActionType): The action type
             value (int, optional): For a raise action, how much to raise *to*.
@@ -989,10 +997,12 @@ class TexasHoldEm:
             raise ValueError("Got arguments for both total and value. Expected only one.")
 
         if value:
-            warnings.warn("The value argument will be redefined in 1.0. Currently, value "
-                          "and total mean to raise *to* the amount given. In 1.0, value will "
-                          "mean to raise an amount more than the current bet amount.",
-                          DeprecationWarning)
+            warnings.warn(
+                "The :code:`value` has been renamed to :code:`total` and will "
+                "be redefined in 1.0.0. Currently, :code:`value` and :code:`total` "
+                "mean to raise *to* the amount given. In 1.0.0, :code:`value` will "
+                "mean to raise an amount more than the current bet amount.",
+                DeprecationWarning)
             total = value
 
         self.validate_move(action=action_type, total=total, throws=True)
