@@ -10,7 +10,7 @@ Texas Hold Em Notation Conventions:
 
 """
 from __future__ import annotations
-from typing import Optional, Union, Tuple, List, Dict
+from typing import Optional, Union, Tuple
 from dataclasses import dataclass
 from pathlib import Path
 import os
@@ -18,6 +18,7 @@ import os
 from texasholdem.game.action_type import ActionType
 from texasholdem.card.card import Card
 from texasholdem.game.hand_phase import HandPhase
+from texasholdem.evaluator import evaluator
 
 
 FILE_EXTENSION = 'pgn'
@@ -52,19 +53,19 @@ class PrehandHistory:
     """
     The id of the player with the small blind
     """
-    player_chips: Dict[int, int]
+    player_chips: dict[int, int]
     """
     The number of chips for each player
     """
-    player_cards: Dict[int, List[Card]]
+    player_cards: dict[int, list[Card]]
     """
     The cards for each player
     """
 
-    def to_string(self, canon_ids: Dict[int, int]) -> str:
+    def to_string(self, canon_ids: dict[int, int]) -> str:
         """
         Arguments:
-            canon_ids (Dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
+            canon_ids (dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
         Returns:
             str: The string representation of the prehand history: blind sizes, chips, and cards
 
@@ -137,10 +138,10 @@ class PlayerAction:
     The amount raised
     """
 
-    def to_string(self, canon_ids: Dict[int, int]) -> str:
+    def to_string(self, canon_ids: dict[int, int]) -> str:
         """
         Arguments:
-            canon_ids (Dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
+            canon_ids (dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
         Returns:
             str: The string representation of a player action: id, action, amount
         """
@@ -167,6 +168,10 @@ class PlayerAction:
         total = None if len(data) <= 2 else int(data[2])
         return PlayerAction(player_id=player_id, action_type=action_type, total=total)
 
+    def __str__(self) -> str:
+        return f"Player {self.player_id} {self.action_type.name}" \
+               f"{f' to {self.total}' if self.action_type == ActionType.RAISE else ''}"
+
 
 @dataclass()
 class BettingRoundHistory:
@@ -174,19 +179,19 @@ class BettingRoundHistory:
     History of a Betting Round
 
     """
-    new_cards: List[Card]
+    new_cards: list[Card]
     """
     The new cards that were added this round
     """
-    actions: List[PlayerAction]
+    actions: list[PlayerAction]
     """
     A list of PlayerActions
     """
 
-    def to_string(self, canon_ids: Dict[int, int]) -> str:
+    def to_string(self, canon_ids: dict[int, int]) -> str:
         """
         Arguments:
-            canon_ids (Dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
+            canon_ids (dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
         Returns:
             str: The string representation of the betting round history:
                 new cards revealed, ordered list of actions
@@ -246,19 +251,19 @@ class SettleHistory:
     History of the Settle Phase
 
     """
-    new_cards: List[Card]
+    new_cards: list[Card]
     """
     The new cards that were added this round
     """
-    pot_winners: Dict[int, Tuple[int, int, List[int]]]
+    pot_winners: dict[int, Tuple[int, int, list[int]]]
     """
     A map from pot_id to a tuple of winner data :code:`amount, best rank, list of winners`
     """
 
-    def to_string(self, canon_ids: Dict[int, int]) -> str:
+    def to_string(self, canon_ids: dict[int, int]) -> str:
         """
         Arguments:
-            canon_ids (Dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
+            canon_ids (dict[int, int]): Map of old_id -> new_id where the new btn_loc is 0
         Returns:
             str: The string representation of the settle history: new cards revealed,
                 and the winners per pot: (pot_id, total_amount, best_rank, winners list)
@@ -305,6 +310,18 @@ class SettleHistory:
                        for pot_name, amount, best_rank, winners_list in pot_winners_data}
         return SettleHistory(new_cards, pot_winners)
 
+    def __str__(self) -> str:
+        pot_lists = []
+        for pot_id, (amount, best_rank, winners_list) in self.pot_winners.items():
+            winners_list = [str(winner) for winner in winners_list]
+            single = len(winners_list) > 0
+            rank_str = f" with a {evaluator.rank_to_string(best_rank)}" if best_rank != -1 else ""
+
+            pot_lists.append(f"Player{'s' if not single else ''} "
+                             f"{', '.join(winners_list)} {'wins' if single else 'splits'} "
+                             f"Pot {pot_id} (Chips {amount}){rank_str}")
+        return "\n".join(pot_lists)
+
 
 @dataclass()
 class History:
@@ -569,3 +586,24 @@ class History:
     def __getitem__(self, hand_phase: HandPhase) -> \
             Union[PrehandHistory, BettingRoundHistory, SettleHistory]:
         return getattr(self, hand_phase.name.lower())
+
+    def __contains__(self, hand_phase: HandPhase) -> bool:
+        if self.__getitem__(hand_phase):
+            return True
+        return False
+
+    def combined_actions(self) -> list[PlayerAction]:
+        """
+        A list of :class:`PlayerAction` objects that was taken.
+
+        Returns:
+            list[PlayerAction]: The cumulative actions of all players in the game
+        """
+        history = []
+        for history_item in (self.preflop,
+                             self.flop,
+                             self.turn,
+                             self.river):
+            if history_item:
+                history.extend(history_item.actions)
+        return history
